@@ -34,7 +34,7 @@ void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType)
     float GNS;			//GNeuron Summary
     
     //Print Message
-    printf("* GNeuron %i Corrected *\n\n",GNIndex+1);
+    printf("* Trying To Correct GNeuron %i... *\n\n",GNIndex+1);
     
     //Get GNeuron Function Type
     GNFT=GMatrix[GNIndex].GetNFT();
@@ -80,7 +80,7 @@ void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType)
         
         {
         
-            printf("Error: Wrong Check Type Specified!\n");
+            printf("Error:Wrong Check Type Specified!\n");
             
             exit(1);
         
@@ -122,7 +122,7 @@ void GErrC(GNeuron *GMatrix,int GNIndex,float Err,int CheckType)
         
         {
         
-            printf("Error: Wrong Check Type Specified!\n");
+            printf("Error:Wrong Check Type Specified!\n");
             
             exit(1);
         
