@@ -105,7 +105,7 @@ void GNeuron::NFunc(int FType)
         else
             Out=0.0;
         
-        printf("Out->%i\n",(int)Out);
+        printf("Out:%i\n",(int)Out);
     
     }
     
@@ -119,7 +119,7 @@ void GNeuron::NFunc(int FType)
         else
             Out=-1.0;
         
-        printf("Out->%i\n",(int)Out);
+        printf("Out:%i\n",(int)Out);
     
     }
     
@@ -135,7 +135,7 @@ void GNeuron::NFunc(int FType)
         else
             Out=-SigFunc;
         
-        printf("Out->%.1f\n",Out);
+        printf("Out:%.1f\n",Out);
     
     }
     
@@ -143,7 +143,7 @@ void GNeuron::NFunc(int FType)
     
     {
     
-        printf("Error: Wrong Neuron Function Type Specified!\n");
+        printf("Error:Wrong Neuron Function Type Specified!\n");
         
         exit(1);
     
@@ -195,7 +195,7 @@ void GNeuron::InData(int InputPin,float Data)
     
     ISPins=InputPin+1;
     
-    printf("InSlot->Input%i:%.1f\n",ISPins,InSlot[InputPin]);
+    printf("Input %i:%.1f\n",ISPins,InSlot[InputPin]);
 
 }
 
