@@ -34,24 +34,29 @@ void GNMS(int SimFunc)
     int NLH;			//Next Layer Head
     int NLE;			//Next Layer End
     int GNFT;			//GNeuron Function Type
-    int Tracer;			//A Tracer
-    int Offset;			//Geeks Hash Table Offset
+    int RSN;			//Registration Serial Number
+    int Sims;			//Simulations Number
     float NewData[MAX_PIN];	//New Data From Inputs GSocket
     float AccErr;		//Acceptable Error (%)
     float GErr;			//G.A.N.N Error (%)
     float Tmp;			//Temp Values
+    FILE *FileToCheck;		//A File Pointer
     
     //Check For Wrong Simulation Mode
     if (SimFunc<0 OR SimFunc>2)
     
     {
     
-        printf("Error: Wrong Simulation Mode Specified!\n");
+        printf("Error:Wrong Simulation Mode Specified!\n");
         
         exit(1);
     
     }
     
+    //Reset Registration Serial Number
+    RegSerNum=0;
+    RSN=0;
+    
     //Learn
     if (SimFunc==0)
     
@@ -105,15 +110,14 @@ void GNMS(int SimFunc)
         
         {
         
+            printf("* Simulation %i *\n\n",n+1);
+            
             //Escape Caption
             ReRoute:;
             
             //Randomize
             GRand();
             
-            //Reset Tracer
-            Tracer=0;
-            
             //Reset GNC
             GNC=-1;
             
@@ -203,7 +207,7 @@ void GNMS(int SimFunc)
                 {
                 
                     //User Defined Connections
-                    printf("Notice: No Connections Specified!\n");
+                    printf("Notice:No Connections Specified!\n");
                     
                     exit(0);
                 
@@ -249,8 +253,30 @@ void GNMS(int SimFunc)
             
             {
             
-                //Save This G.A.N.N To GKDB
-                GSaveData(GANN);
+                if (RegSerNum==0)
+                
+                {
+                
+                    //Produce A Registration Serial Number
+                    RegSerNum=(int)GGenData(1,\
+                    ((Inputs+Outputs)*GNC*time(0))/SimNum);
+                    
+                    //Initialize GSims
+                    FileToCheck=fopen("GSims","a");
+                    
+                    //Save Registration Serial Number
+                    fprintf(FileToCheck,"%i\n",RegSerNum);
+                    
+                    //Save Simulations Number
+                    fprintf(FileToCheck,"%i\n",SimNum);
+                    
+                    //Close GSims
+                    fclose(FileToCheck);
+                
+                }
+                
+                //Save This G.A.N.N To The GKDB
+                GSaveData(GANN,RegSerNum,n+1);
                 
                 //Print Outputs GSocket
                 printf("----- Outputs GSocket -----\n\n");
@@ -284,7 +310,7 @@ void GNMS(int SimFunc)
                 
                 {
                 
-                    printf("Error Correction [Output GPin%i]\n\n",i+1);
+                    printf("Error Correction [Output GPin %i]\n\n",i+1);
                     
                     for (j=0;j<GNNum;j++)
                     
@@ -316,6 +342,15 @@ void GNMS(int SimFunc)
         
         //Unload G.A.N.N From Memory
         delete []GANN;
+        
+        //Initialize GRegs
+        FileToCheck=fopen("GRegs","a");
+        
+        //Save G.A.N.N Registrations
+        fprintf(FileToCheck,"%i\n",RegSerNum);
+        
+        //Close GRegs
+        fclose(FileToCheck);
     
     }
     
@@ -324,48 +359,63 @@ void GNMS(int SimFunc)
     
     {
     
-        //Reset Offset
-        Offset=-1;
-        
-        //Run GRMC (User Interaction - Get User Values Number)
-        n=GRMC();
-        
         //Create A New G.A.N.N In Memory (G.A.N.N Matrix)
         GNeuron *GANN;
         GANN=new GNeuron[MAX_MATRIX];
         
+        //Run GRMC (User Interaction - Load Offset And RegSerNum)
+        GRMC();
+        
+        //Initialize GSims
+        FileToCheck=fopen("GSims","r");
+        
+        //Get Simulations Number
+        while ((i=feof(FileToCheck))==FALSE)
+        
+        {
+        
+            fscanf(FileToCheck,"%i\n",&RSN);
+            fscanf(FileToCheck,"%i\n",&Sims);
+            
+            if (RegSerNum==RSN)
+                break;
+        
+        }
+        
+        //Close GSims
+        fclose(FileToCheck);
+        
+        //Reset n
+        n=0;
+        
         //Start Simulation
         printf("Running...\n\n");
         
         //Escape Caption
         ReRun:;
         
-        //Increase Offset
-        if (Offset<n-1)
-            Offset++;
+        //Increase Simulations Pointer
+        n++;
+        
+        //Read GKDB
+        GReadData(GANN,Offset,RegSerNum,n);
+        
+        //Compare User Inputs With G.A.N.N Inputs
+        if (UserInp>Inputs)
+        
+        {
+        
+            printf("Error:Too Many Inputs For This Registration!\n");
+            
+            exit(1);
+        
+        }
         
-        //Read GKDB And Load It To G.A.N.N
-	GReadData(GANN,Offset);
-	
-	//Check User Values Number
-	if (n>Inputs)
-	
-	{
-	
-	    printf("Error: User Values Number Are More Than Inputs!\n");
-	    
-	    exit(1);
-	
-	}
-	
 	//Check GMap Simulation Type So As To Set GNeurons Function Type
 	if (GMSType==0)
 	    GNFT=0;
 	else
 	    GNFT=2;
-	
-        //Reset Tracer
-        Tracer=0;
         
         //Reset GNC
         GNC=-1;
@@ -403,7 +453,7 @@ void GNMS(int SimFunc)
                     {
                     
                         for (p=0;p<Inputs;p++)
-                            GANN[GNC].InData(p-NLH,UserVal[Offset]);
+                            GANN[GNC].InData(p-NLH,UserVal[p]);
                     
                     }
                     
@@ -441,6 +491,9 @@ void GNMS(int SimFunc)
         
         }
         
+        //Reset j
+        j=0;
+        
         //Get G.A.N.N Values
         for (i=NLH;i<(NLH+NLE);i++)
         
@@ -456,7 +509,7 @@ void GNMS(int SimFunc)
                 
                 {
                 
-                    printf("\n* Output GPin%i *\n",Offset+1);
+                    printf("\n* Output GPin %i *\n",i-NLH+1);
                     printf("Value Found - Little Acurracy!\n\n");
                 
                 }
@@ -465,29 +518,33 @@ void GNMS(int SimFunc)
                 
                 {
                 
-                    printf("\n* Output GPin%i *\n",Offset+1);
+                    printf("\n* Output GPin %i *\n",i-NLH+1);
                     printf("Value Found!\n\n");
                 
                 }
                 
-                if (Offset==n-1)
-                    break;
-                else
-                    goto ReRun;
-            
-            }
-            
-            else if (Offset==n-1)
-            
-            {
-            
-                printf("Nothing Found...Finished!\n");
+                j=1;
                 
                 break;
             
             }
-            
-            printf("Nothing Found...System Will Rerun!\n\n");
+        
+        }
+        
+        //Final Checks
+        if (j==0 AND n==Sims)
+        
+        {
+        
+            printf("\nNothing Found!\n\n");
+        
+        }
+        
+        else if (j==0 AND n!=Sims)
+        
+        {
+        
+            printf("\nNothing Found...System Will Rerun!\n\n");
             
             goto ReRun;
         
@@ -497,10 +554,6 @@ void GNMS(int SimFunc)
         delete []GANN;
     
     }
-    
-    //Clean Up
-    system("touch GIOD GMap");
-    system("rm GIOD GMap");
 
 }
 
