@@ -23,84 +23,91 @@
 
 
 //Geeks Read Data (Function)
-void GReadData(GNeuron *GMatrix,int RegNum)
+void GReadData(GNeuron *GMatrix,long GOffset,int GRegSerNum,int GSimNum)
 
 {
 
     //Variables
-    int i,j,k;
+    int i,j,k,n;
+    int RSN;
     float d;
     FILE *FileToOpen;
     
-    //Reset j
+    //Reset
+    i=0;
     j=0;
+    k=0;
+    n=0;
+    SimNum=0;
     
-    //Initialize GHT
-    FileToOpen=fopen("GHT","r");
-    
-    //Error Check
-    if (FileToOpen==NULL)
+    //Error Checks
+    if (GOffset<0)
     
     {
     
-        printf("Error: GKDB Has Not Been Found!\n");
+        printf("Error:Wrong Offset Specified!\n");
         
         exit(1);
     
     }
     
-    //Read Offset
-    for (i=0;i<RegNum-1;i++)
-        fscanf(FileToOpen,"%i\n",&j);
-    
-    //Close GHT
-    fclose(FileToOpen);
-    
     //Initialize GKDB
     FileToOpen=fopen("GKDB","r");
     
     //Set Pointer To The Right Offset
-    fseek(FileToOpen,j,SEEK_SET);
+    fseek(FileToOpen,GOffset,SEEK_SET);
     
-    //Read Starting Header
-    fscanf(FileToOpen,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
-    &SimNum,&ECT,&GMSType,&GMCType,&LearnTH,&GNNum,&Layers,&Inputs,&Outputs);
-    
-    //Read GMap Layers
-    for (i=0;i<Layers;i++)
-        fscanf(FileToOpen,"%i\n",&GMap[i]);
-    
-    //Read GNeurons Options
-    for (i=0;i<GNNum;i++)
+    while ((i=feof(FileToOpen))==FALSE)
     
     {
     
-        //Read Input Slot Pins Of This GNeuron
-        fscanf(FileToOpen,"%i\n",&k);
+        if (GSimNum==SimNum)
+            break;
         
-        for (j=0;j<k;j++)
+        //Read Registration Serial Number
+        fscanf(FileToOpen,"%i\n",&RSN);
+        
+        //Read The Rest Of The Starting Header
+        fscanf(FileToOpen,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",&SimNum,&ECT,\
+        &GMSType,&GMCType,&LearnTH,&GNNum,&Layers,&Inputs,&Outputs);
+        
+        //Read GMap Layers
+        for (i=0;i<Layers;i++)
+            fscanf(FileToOpen,"%i\n",&GMap[i]);
+        
+        //Read GNeurons Options
+        for (i=0;i<GNNum;i++)
         
         {
         
+            //Read Input Slot Pins Of This GNeuron
+            fscanf(FileToOpen,"%i\n",&k);
+            
+            for (j=0;j<k;j++)
+            
+            {
+            
+                fscanf(FileToOpen,"%f\n",&d);
+                GMatrix[i].SetWeights(j,d);
+            
+            }
+            
+            fscanf(FileToOpen,"%i\n",&j);
+            GMatrix[i].SetNFT(j);
             fscanf(FileToOpen,"%f\n",&d);
-            GMatrix[i].SetWeights(j,d);
+            GMatrix[i].Mod=d;
         
         }
         
-        fscanf(FileToOpen,"%i\n",&j);
-        GMatrix[i].SetNFT(j);
-        fscanf(FileToOpen,"%f\n",&d);
-        GMatrix[i].Mod=d;
-    
-    }
-    
-    //Read Output Socket Values
-    for (i=0;i<Outputs;i++)
-    
-    {
-    
-        fscanf(FileToOpen,"%f\n",&GMinData[i]);
-        fscanf(FileToOpen,"%f\n",&GMaxData[i]);
+        //Read Output Socket Values
+        for (i=0;i<Outputs;i++)
+        
+        {
+        
+            fscanf(FileToOpen,"%f\n",&GMinData[i]);
+            fscanf(FileToOpen,"%f\n",&GMaxData[i]);
+        
+        }
     
     }
     
