@@ -23,21 +23,24 @@
 
 
 //Geeks Save Data (Function)
-void GSaveData(GNeuron *GMatrix)
+void GSaveData(GNeuron *GMatrix,int GRegSerNum,int GSimNum)
 
 {
 
     //Variables
     int i,j;
-    long k;
+    long GOffset;
     FILE *FileToSave;
     
     //Initialize GKDB
     FileToSave=fopen("GKDB","a");
     
+    //Save Registration Serial Number
+    fprintf(FileToSave,"%i\n",GRegSerNum);
+    
     //Set Starting Header
     fprintf(FileToSave,"%i\n%i\n%i\n%i\n%f\n%i\n%i\n%i\n%i\n",\
-    SimNum,ECT,GMSType,GMCType,LearnTH,GNNum,Layers,Inputs,Outputs);
+    GSimNum,ECT,GMSType,GMCType,LearnTH,GNNum,Layers,Inputs,Outputs);
     
     //Save GMap Layers
     for (i=0;i<Layers;i++)
@@ -70,7 +73,7 @@ void GSaveData(GNeuron *GMatrix)
     }
     
     //Get File Position Indicator
-    k=ftell(FileToSave);
+    GOffset=ftell(FileToSave);
     
     //Close GKDB
     fclose(FileToSave);
@@ -78,8 +81,11 @@ void GSaveData(GNeuron *GMatrix)
     //Initialize GHT
     FileToSave=fopen("GHT","a");
     
+    //Save Registration Serial Number
+    fprintf(FileToSave,"%i\n",GRegSerNum);
+    
     //Save Offset
-    fprintf(FileToSave,"%i\n",k);
+    fprintf(FileToSave,"%i\n",GOffset);
     
     //Close GHT
     fclose(FileToSave);
