@@ -53,7 +53,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Too Many GPins!\n");
+        printf("Error:Too Many GPins!\n");
         
         exit(1);
     
@@ -92,7 +92,7 @@ void GSNMC()
     }
     
     printf("Now Please Assign Values To The GPins\n");
-    printf("(Examples: 1 Or 5,20.6)\n\n");
+    printf("(Examples:1 Or 5,20.6)\n\n");
     
     for (j=i;j>=1;j--)
     
@@ -133,7 +133,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Too Many GPins!\n");
+        printf("Error:Too Many GPins!\n");
         
         exit(1);
     
@@ -172,7 +172,7 @@ void GSNMC()
     }
     
     printf("Now Please Assign Values To The GPins\n");
-    printf("(Examples: 1 Or 5,20.6)\n\n");
+    printf("(Examples:1 Or 5,20.6)\n\n");
     
     for (j=i;j>=1;j--)
     
@@ -301,7 +301,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Wrong GMap Connections Type!\n");
+        printf("Error:Wrong GMap Connections Type!\n");
         
         exit(1);
     
@@ -321,7 +321,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Too Many GNeurons!\n");
+        printf("Error:Too Many GNeurons!\n");
         
         exit(1);
     
@@ -332,7 +332,7 @@ void GSNMC()
     
     {
     
-        printf("Error: GNeurons Are Less Than The Outputs!\n");
+        printf("Error:GNeurons Are Less Than The Outputs!\n");
         
         exit(1);
     
@@ -416,7 +416,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Simulations Must Be A Positive Number!\n");
+        printf("Error:Simulations Must Be A Positive Number!\n");
         
         exit(1);
     
@@ -426,7 +426,7 @@ void GSNMC()
     
     //Set Threshold
     printf("Please Specify Learning Mode Threshold\n");
-    printf("(Threshold Must Be A Positive Value Between 1-100%)\n");
+    printf("(Threshold Must Be A Positive Value Between 1-100%%)\n");
     printf("Choice:");
     
     scanf("%f",&LearnTH);
@@ -435,7 +435,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Threshold Value Must Be Between 1-100%!\n");
+        printf("Error:Threshold Value Must Be Between 1-100%%!\n");
         
         exit(1);
     
@@ -471,7 +471,7 @@ void GSNMC()
     
     {
     
-        printf("Error: Too Many Layers Alocated For GMap!\n");
+        printf("Error:Too Many Layers Alocated For GMap!\n");
         
         exit(1);
     
