@@ -193,13 +193,13 @@ float GGenData(int FuncType,float Val);
 float GGenData(float Val1,float Val2);
 
 //Geeks Read Data (Function)
-void GReadData(GNeuron *GMatrix,int RegNum);
+void GReadData(GNeuron *GMatrix,long GOffset,int GRegSerNum,int GSimNum);
 
 //Geeks Save Data (Function)
-void GSaveData(GNeuron *GMatrix);
+void GSaveData(GNeuron *GMatrix,int GRegSerNum,int GSimNum);
 
 //Geeks Remove Data (Function)
-void GRemData(int RegNum);
+void GRemData(int GRegSerNum);
 
 //Geeks Socket And Neural Map Creator (Function)
 void GSNMC();
@@ -208,7 +208,7 @@ void GSNMC();
 void GNMS(int SimFunc);
 
 //Geeks Runtime Manager Console (Function)
-int GRMC();
+void GRMC();
 
 GSocket InSocket;		//Inputs GSocket
 GSocket OutSocket;		//Outputs GSocket
